==> libgtop-2.10.0.tar.bz2: libgtop-2.10.0/lib/read.c <==
/* $Id: read.c,v 1.21 2005/02/15 12:48:33 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/read.h>
#include <glibtop/error.h>
#include "libgtop-i18n.h"


/* Reads some data from server. */

static void
do_read (int s, void *ptr, size_t total_size)
{
	ssize_t nread;

	if(!total_size) return;

	while (total_size && (nread = recv (s, ptr, total_size, 0)) > 0) {
		total_size -= nread;
		ptr = (char*)ptr + nread;
	}

	if(nread == 0)
		close (s);
	else if (nread < 0)
		glibtop_error_io ("recv");
}

void
glibtop_read_l (glibtop *server, size_t size, void *buf)
{
	glibtop_init_r (&server, 0, 0);

#ifdef DEBUG
	fprintf (stderr, "LIBRARY: really reading %d bytes.\n", size);
#endif

	if (server->socket) {
		do_read (server->socket, buf, size);
	} else {
		if(read (server->input [0], buf, size) < 0)
			glibtop_error_io_r (
				server,
				ngettext ("read %d byte",
					  "read %d bytes", size),
				size);
	}
}

==> libgtop-2.14.6.tar.bz2: libgtop-2.14.6/lib/read.c <==
/* $Id: read.c 2478 2006-04-10 08:41:46Z bdejean $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/read.h>
#include <glibtop/error.h>
#include <glib/gi18n-lib.h>


/* Reads some data from server. */

static void
do_read (int s, void *ptr, size_t total_size)
{
	ssize_t nread;

	if(!total_size) return;

	while (total_size && (nread = recv (s, ptr, total_size, 0)) > 0) {
		total_size -= nread;
		ptr = (char*)ptr + nread;
	}

	if(nread == 0)
		close (s);
	else if (nread < 0)
		glibtop_error_io ("recv");
}

void
glibtop_read_l (glibtop *server, size_t size, void *buf)
{
	glibtop_init_r (&server, 0, 0);

#ifdef DEBUG
	fprintf (stderr, "LIBRARY: really reading %d bytes.\n", (int)size);
#endif

	if (server->socket) {
		do_read (server->socket, buf, size);
	} else {
		if(read (server->input [0], buf, size) < 0)
			glibtop_error_io_r (
				server,
				ngettext ("read %d byte",
					  "read %d bytes", size),
				(int)size);
	}
}
